.. jaqpotpy documentation master file, created by
   sphinx-quickstart on Tue Nov  5 14:05:09 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

jaqpotpy documentation
======================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.


.. toctree::
   :maxdepth: 4
   :caption: Contents:

   jaqpotpy
